@@ -27,12 +27,8 @@ INDEX_NEGATIVE_ERROR_MSG = "ERR value is out of range, must be positive"
 # ZADD_NX_XX_ERROR_MSG6 = "ERR ZADD allows either 'nx' or 'xx', not both"
 ZADD_NX_XX_ERROR_MSG = "ERR XX and NX options at the same time are not compatible"
 ZADD_INCR_LEN_ERROR_MSG = "ERR INCR option supports a single increment-element pair"
-ZADD_NX_GT_LT_ERROR_MSG = (
-    "ERR GT, LT, and/or NX options at the same time are not compatible"
-)
-NX_XX_GT_LT_ERROR_MSG = (
-    "ERR NX and XX, GT or LT options at the same time are not compatible"
-)
+ZADD_NX_GT_LT_ERROR_MSG = "ERR GT, LT, and/or NX options at the same time are not compatible"
+NX_XX_GT_LT_ERROR_MSG = "ERR NX and XX, GT or LT options at the same time are not compatible"
 EXPIRE_UNSUPPORTED_OPTION = "ERR Unsupported option {}"
 ZUNIONSTORE_KEYS_MSG = "ERR at least 1 input key is needed for {}"
 WRONG_ARGS_MSG7 = "ERR Wrong number of args calling Redis command from script"
@@ -49,9 +45,7 @@ NO_MATCHING_SCRIPT_MSG = "NOSCRIPT No matching script. Please use EVAL."
 GLOBAL_VARIABLE_MSG = "ERR Script attempted to set global variables: {}"
 COMMAND_IN_SCRIPT_MSG = "ERR This Redis command is not allowed from scripts"
 BAD_SUBCOMMAND_MSG = "ERR Unknown {} subcommand or wrong # of args."
-BAD_COMMAND_IN_PUBSUB_MSG = (
-    "ERR only (P)SUBSCRIBE / (P)UNSUBSCRIBE / PING / QUIT allowed in this context"
-)
+BAD_COMMAND_IN_PUBSUB_MSG = "ERR only (P)SUBSCRIBE / (P)UNSUBSCRIBE / PING / QUIT allowed in this context"
 CONNECTION_ERROR_MSG = "FakeRedis is emulating a connection error."
 REQUIRES_MORE_ARGS_MSG = "ERR {} requires {} arguments or more."
 LOG_INVALID_DEBUG_LEVEL_MSG = "ERR Invalid debug level."
@@ -67,13 +61,9 @@ JSON_WRONG_REDIS_TYPE = "ERR Existing key has wrong Redis type"
 JSON_KEY_NOT_FOUND = "ERR could not perform this operation on a key that doesn't exist"
 JSON_PATH_NOT_FOUND_OR_NOT_STRING = "ERR Path '{}' does not exist or not a string"
 JSON_PATH_DOES_NOT_EXIST = "ERR Path '{}' does not exist"
-LCS_CANT_HAVE_BOTH_LEN_AND_IDX = (
-    "ERR If you want both the length and indexes, please just use IDX."
-)
+LCS_CANT_HAVE_BOTH_LEN_AND_IDX = "ERR If you want both the length and indexes, please just use IDX."
 BIT_ARG_MUST_BE_ZERO_OR_ONE = "ERR The bit argument must be 1 or 0."
-XADD_ID_LOWER_THAN_LAST = (
-    "ERR The ID specified in XADD is equal or smaller than the target stream top item"
-)
+XADD_ID_LOWER_THAN_LAST = "ERR The ID specified in XADD is equal or smaller than the target stream top item"
 XADD_INVALID_ID = "ERR Invalid stream ID specified as stream command argument"
 XGROUP_BUSYGROUP = "ERR BUSYGROUP Consumer Group name already exists"
 XREADGROUP_KEY_OR_GROUP_NOT_FOUND_MSG = (
@@ -99,8 +89,7 @@ NONSCALING_FILTERS_CANNOT_EXPAND_MSG = "Nonscaling filters cannot expand"
 ITEM_EXISTS_MSG = "item exists"
 NOT_FOUND_MSG = "not found"
 INVALID_BITFIELD_TYPE = (
-    "ERR Invalid bitfield type. Use something like i16 u8. "
-    "Note that u64 is not supported but i64 is."
+    "ERR Invalid bitfield type. Use something like i16 u8. " "Note that u64 is not supported but i64 is."
 )
 INVALID_OVERFLOW_TYPE = "ERR Invalid OVERFLOW type specified"
 
