@@ -2,7 +2,7 @@ from typing import Any, List, Union
 
 from fakeredis import _msgs as msgs
 from fakeredis._commands import command, DbIndex
-from fakeredis._helpers import SimpleError, OK, SimpleString, Database
+from fakeredis._helpers import SimpleError, OK, SimpleString, Database, casematch
 
 PONG = SimpleString(b"PONG")
 
@@ -37,3 +37,9 @@ class ConnectionCommandsMixin:
         self._db = self._server.dbs[index]
         self._db_num = index  # type: ignore
         return OK
+
+    @command(name="CLIENT SETINFO", fixed=(bytes, bytes), repeat=())
+    def client_setinfo(self, lib_data: bytes, value: bytes) -> SimpleString:
+        if not casematch(lib_data, b"LIB-NAME") and not casematch(lib_data, b"LIB-VER"):
+            raise SimpleError(msgs.SYNTAX_ERROR_MSG)
+        return OK
